@@ -134,27 +134,42 @@
 
 {#
   Postgres tables have a maximum length off 63 characters, anything longer is silently truncated.
-  Temp relations add a lot of extra characters to the end of table namers to ensure uniqueness.
+  Temp and backup relations add a lot of extra characters to the end of table names to ensure uniqueness.
   To prevent this going over the character limit, the base_relation name is truncated to ensure
-  that name + suffix + uniquestring is < 63 characters.  
+  that name + suffix + uniquestring is < 63 characters.
 #}
-{% macro postgres__make_temp_relation(base_relation, suffix) %}
-    {% set dt = modules.datetime.datetime.now() %}
-    {% set dtstring = dt.strftime("%H%M%S%f") %}
-    {% set suffix_length = suffix|length + dtstring|length %}
+
+{% macro postgres__make_relation_with_suffix(base_relation, suffix, dstring) %}
+    {% if dstring %}
+      {% set dt = modules.datetime.datetime.now() %}
+      {% set dtstring = dt.strftime("%H%M%S%f") %}
+      {% set suffix = suffix ~ dtstring %}
+    {% endif %}
+    {% set suffix_length = suffix|length %}
     {% set relation_max_name_length = 63 %}
     {% if suffix_length > relation_max_name_length %}
-        {% do exceptions.raise_compiler_error('Temp relation suffix is too long (' ~ suffix|length ~ ' characters). Maximum length is ' ~ (relation_max_name_length - dtstring|length) ~ ' characters.') %}
+        {% do exceptions.raise_compiler_error('Relation suffix is too long (' ~ suffix_length ~ ' characters). Maximum length is ' ~ relation_max_name_length ~ ' characters.') %}
     {% endif %}
-    {% set tmp_identifier = base_relation.identifier[:relation_max_name_length - suffix_length] ~ suffix ~ dtstring %}
-    {% do return(base_relation.incorporate(
-                                  path={
-                                    "identifier": tmp_identifier,
-                                    "schema": none,
-                                    "database": none
-                                  })) -%}
+    {% set identifier = base_relation.identifier[:relation_max_name_length - suffix_length] ~ suffix %}
+
+    {{ return(base_relation.incorporate(path={"identifier": identifier })) }}
+
+  {% endmacro %}
+
+{% macro postgres__make_intermediate_relation(base_relation, suffix) %}
+    {{ return(postgres__make_relation_with_suffix(base_relation, suffix, dstring=False)) }}
 {% endmacro %}
 
+{% macro postgres__make_temp_relation(base_relation, suffix) %}
+    {% set temp_relation = postgres__make_relation_with_suffix(base_relation, suffix, dstring=True) %}
+    {{ return(temp_relation.incorporate(path={"schema": none,
+                                              "database": none})) }}
+{% endmacro %}
+
+{% macro postgres__make_backup_relation(base_relation, backup_relation_type, suffix) %}
+    {% set backup_relation = postgres__make_relation_with_suffix(base_relation, suffix, dstring=False) %}
+    {{ return(backup_relation.incorporate(type=backup_relation_type)) }}
+{% endmacro %}
 
 {#
   By using dollar-quoting like this, users can embed anything they want into their comments
@@ -187,3 +202,16 @@
     comment on column {{ relation }}.{{ adapter.quote(column_name) if column_dict[column_name]['quote'] else column_name }} is {{ escaped_comment }};
   {% endfor %}
 {% endmacro %}
+
+{%- macro postgres__get_show_grant_sql(relation) -%}
+  select grantee, privilege_type
+  from {{ relation.information_schema('role_table_grants') }}
+      where grantor = current_role
+        and grantee != current_role
+        and table_schema = '{{ relation.schema }}'
+        and table_name = '{{ relation.identifier }}'
+{%- endmacro -%}
+
+{% macro postgres__copy_grants() %}
+    {{ return(False) }}
+{% endmacro %}
